==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-menu-plugin-mate-terminal/translations/peony-mate-terminal-extension_kk_KZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>Peony::MateTerminalMenuPlugin</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="150"/>
        <location filename="../mate-terminal-menu-plugin.cpp" line="169"/>
        <source>Open Directory in Terminal</source>
        <translation>Терминалда каталогты ашу</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="43"/>
        <source>Peony-Qt Mate Terminal Menu Extension</source>
        <translation>Peony-Qt Mate терминалының мәзірін кеңейту</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="44"/>
        <source>Open Terminal with menu.</source>
        <translation>Мәзірмен Терминалды ашыңыз.</translation>
    </message>
    <message>
        <source>Open Directory in T&amp;erminal</source>
        <translation type="vanished">打开终端(&amp;E)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="119"/>
        <source>Open terminal fail</source>
        <translation>Терминалды ашу жаңылысы</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="120"/>
        <source>Open terminal failed, did you removed the default terminal?  If it&apos;s true please reinstall it.</source>
        <translation>Терминалды ашу сәтсіз аяқталды, әдепкі терминалды жойдыңыз ба?  Егер шындыққа сәйкес келсе, оны қайта орнатыңыз.</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?  If you have reinstalled it please logout and relogin.</source>
        <translation type="vanished">打开终端失败，您是否卸载过默认终端？如果已经重新安装了，请注销并重新登录后生效。</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?</source>
        <translation type="vanished">打开终端失败，您是否卸载了默认的终端应用？</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-menu-plugin-mate-terminal/translations/peony-mate-terminal-extension_kk_KZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>Peony::MateTerminalMenuPlugin</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="188"/>
        <location filename="../mate-terminal-menu-plugin.cpp" line="207"/>
        <source>Open Directory in Terminal</source>
        <translation>ورتاسندا ايقٸن باس مازمۇن</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="43"/>
        <source>Peony-Qt Mate Terminal Menu Extension</source>
        <translation>مودەنگۈل-Qt Mate سوڭعٸ ۇشٸ تٸزٸمدٸكدٸ ۇزارتۋ</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="44"/>
        <source>Open Terminal with menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Terminal with menu.</source>
        <translation type="vanished">Мәзірмен Терминалды ашыңыз.</translation>
    </message>
    <message>
        <source>Open Directory in T&amp;erminal</source>
        <translation type="vanished">打开终端(&amp;E)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="151"/>
        <source>Open terminal fail</source>
        <translation>ايقٸن سوڭعٸ ۇشٸ جەڭىلىپ قالدى</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="152"/>
        <source>Open terminal failed, did you removed the default terminal?  If it&apos;s true please reinstall it.</source>
        <translation>ايقٸن سوڭعٸ ۇشٸ جەڭىلىپ قالدى، سۈكۈتتىكى سوڭعٸ ۇشٸنى چىقىرىۋەتتىڭىزمۇ؟  قيسٸق شىن بولسا قاتە تۇسىرىڭىز.</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?  If you have reinstalled it please logout and relogin.</source>
        <translation type="vanished">打开终端失败，您是否卸载过默认终端？如果已经重新安装了，请注销并重新登录后生效。</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?</source>
        <translation type="vanished">打开终端失败，您是否卸载了默认的终端应用？</translation>
    </message>
</context>
</TS>
